customer_schema = [
    'address_city',
    'address_country',
    'address_state',
    'created',
    'email',
    'id',
    'invoice_prefix',
    'livemode',
    'name',
    'subscriptions_data_billing_cycle_anchor',
    'subscriptions_data_cancel_at',
    'subscriptions_data_created',
    'subscriptions_data_current_period_end',
    'subscriptions_data_current_period_start',
    'subscriptions_data_customer',
    'subscriptions_data_default_payment_method',
    'subscriptions_data_id',
    'subscriptions_data_items_data_created',
    'subscriptions_data_items_data_id',
    'subscriptions_data_items_data_object',
    'subscriptions_data_items_data_plan_active',
    'subscriptions_data_items_data_plan_amount',
    'subscriptions_data_items_data_plan_amount',
    'subscriptions_data_items_data_plan_id',
    'subscriptions_data_items_data_plan_imnterval',
    'subscriptions_data_items_data_plan_interval_count',
    'subscriptions_data_items_data_plan_livemode',
    'subscriptions_data_items_data_plan_metadata_maxSpaceBytes',
    'subscriptions_data_items_data_plan_metadata_name',
    'subscriptions_data_items_data_plan_planType',
    'subscriptions_data_items_data_plan_product',
    'subscriptions_data_items_data_price_active',
    'subscriptions_data_items_data_price_id',
    'subscriptions_data_items_data_price_livemode',
    'subscriptions_data_items_data_price_metadata_maxSpaceBytes',
    'subscriptions_data_items_data_price_metadata_name',
    'subscriptions_data_items_data_price_metadata_planType',
    'subscriptions_data_items_data_price_product',
    'subscriptions_data_items_data_price_recurring_interval',
    'subscriptions_data_items_data_price_interval_count',
    'subscriptions_data_items_data_price_trial_period_days',
    'subscriptions_data_items_data_price_unit_amount',
    'subscriptions_data_items_data_price_type',
    'subscriptions_data_items_data_subscription',
    'subscriptions_latest_invoice',
    'subscriptions_data_discount_checkout_session',
    'subscriptions_data_discount_coupon_amount_off',
    'subscriptions_data_discount_coupon_duration',
    'subscriptions_data_discount_coupon_duration_in_months',
    'subscriptions_data_discount_coupon_name',
    'subscriptions_data_discount_coupon_percent_off',
    'subscriptions_data_discount_id',
    'subscriptions_data_discount_promotion_code',
]
